#!/bin/bash
#This script will help to run a workflow in a docker image. 

if [ $# -lt 4 ]
then
  echo usage : $0 dataDir resultsDir configFile nbCores '[dockerHub|local]'
  exit
fi
# Docker volumes
# MBB Workflows reads data from /Data and write results to /Results

Data=$1
Results=$2

if [ ! -d "$Data" ]; then
  echo "can't find $Data directory !"
  exit;
fi

mkdir -p $Results

DOCK_VOL+=" --mount type=bind,src=$Data,dst=/Data"
DOCK_VOL+=" --mount type=bind,src=$Results/Results,dst=/Results"

config=$3
cores=$4

if [ $# -lt 5 ]
then
    APP_IMG="mbbteam/radseqdenovo:latest"  
else 
    IMG_SRC=$5
    case $IMG_SRC in
        docker )
            APP_IMG="mbbteam/radseqdenovo:latest"  ;;
        local)
            docker build . -t radseqdenovo:latest 
            APP_IMG="radseqdenovo:latest" ;;
        mbb)    
            #APP_IMG="X.X.X.X:5000/radseqdenovo:latest" ;;
    esac
fi

CONTAINER_ID=$( docker run --rm $DOCK_VOL $APP_IMG snakemake -s /workflow/Snakefile all --configfile $config --cores $cores)

if [ $CONTAINER_ID ]
then
    echo " "
    echo Results were written to    : $3
    echo " "
else
    echo Failed to run the docker container  !!
fi
